@@ -13,7 +13,7 @@ use ckb_types::{
         IndexTransaction, OutPoint,
     },
 };
-use std::collections::{HashMap, HashSet};
+use std::collections::HashMap;
 use std::iter::FromIterator;
 use std::sync::Arc;
 
@@ -49,7 +49,7 @@ fn test_accept_block() {
         .transactions(vec![tx1, tx2.clone()])
         .uncle(uncle.as_uncle())
         .build();
-    let prefilled = HashSet::from_iter(vec![0usize].into_iter());
+    let prefilled = vec![0usize].into_iter().collect();
 
     let compact_block = CompactBlock::build_from_block(&block, &prefilled);
     let hash = compact_block.header().calc_header_hash();
@@ -74,8 +74,8 @@ fn test_accept_block() {
         .uncles(vec![uncle.as_uncle().data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         block_transactions.as_reader(),
@@ -92,8 +92,7 @@ fn test_accept_block() {
     assert!(relayer
         .shared
         .state()
-        .inflight_proposals()
-        .contains(&tx3.proposal_short_id()));
+        .contains_inflight_proposal(&tx3.proposal_short_id()));
 }
 
 #[test]
@@ -115,7 +114,7 @@ fn test_unknown_request() {
         .transactions(vec![tx1, tx2.clone()])
         .build();
 
-    let prefilled = HashSet::from_iter(vec![0usize].into_iter());
+    let prefilled = vec![0usize].into_iter().collect();
 
     let compact_block = CompactBlock::build_from_block(&block, &prefilled);
 
@@ -136,8 +135,8 @@ fn test_unknown_request() {
         .transactions(vec![tx2.data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         block_transactions.as_reader(),
@@ -200,8 +199,8 @@ fn test_invalid_transaction_root() {
         .transactions(vec![tx2.data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         block_transactions.as_reader(),
@@ -266,7 +265,7 @@ fn test_collision_and_send_missing_indexes() {
         .transactions(vec![tx1, tx2.clone(), fake_tx])
         .build_unchecked();
 
-    let prefilled = HashSet::from_iter(vec![0usize].into_iter());
+    let prefilled = vec![0usize].into_iter().collect();
 
     let compact_block = CompactBlock::build_from_block(&block, &prefilled);
 
@@ -285,7 +284,7 @@ fn test_collision_and_send_missing_indexes() {
             hash.clone(),
             (
                 compact_block,
-                HashMap::from_iter(vec![(peer_index, (vec![1], vec![]))]),
+                vec![(peer_index, (vec![1], vec![]))].into_iter().collect(),
             ),
         );
     }
@@ -295,8 +294,8 @@ fn test_collision_and_send_missing_indexes() {
         .transactions(vec![tx2.data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         block_transactions.as_reader(),
@@ -338,8 +337,8 @@ fn test_collision_and_send_missing_indexes() {
         .transactions(vec![tx2.data(), tx3.data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         new_block_transactions.as_reader(),
@@ -380,7 +379,7 @@ fn test_missing() {
         .transactions(vec![tx1, tx2.clone(), tx3])
         .build();
 
-    let prefilled = HashSet::from_iter(vec![0usize].into_iter());
+    let prefilled = vec![0usize].into_iter().collect();
 
     let compact_block = CompactBlock::build_from_block(&block, &prefilled);
 
@@ -402,8 +401,8 @@ fn test_missing() {
         .transactions(vec![tx2.data()].pack())
         .build();
 
-    let mock_protocal_context = MockProtocolContext::new(SupportProtocols::Relay);
-    let nc = Arc::new(mock_protocal_context);
+    let mock_protocol_context = MockProtocolContext::new(SupportProtocols::Relay);
+    let nc = Arc::new(mock_protocol_context);
 
     let process = BlockTransactionsProcess::new(
         block_transactions.as_reader(),
